@@ -155,9 +155,9 @@ impl<A> Array<A, Ix>
         }
     }
 
-    /// Create a one-dimensional array from an iterator.
-    pub fn from_iter<I: Iterator<Item=A>>(it: I) -> Array<A, Ix> {
-        Array::from_vec(it.collect())
+    /// Create a one-dimensional array from an iterable.
+    pub fn from_iter<I: IntoIterator<Item=A>>(iterable: I) -> Array<A, Ix> {
+        Self::from_vec(iterable.into_iter().collect())
     }
 }
 
@@ -182,10 +182,18 @@ impl<A, D> Array<A, D> where D: Dimension
         Array::from_elem(dim, libnum::zero())
     }
 
+    /// Construct an Array with default values, dimension `dim`.
+    pub fn default(dim: D) -> Array<A, D>
+        where A: Default
+    {
+        let v = (0..dim.size()).map(|_| A::default()).collect();
+        unsafe {
+            Array::from_vec_dim(dim, v)
+        }
+    }
+
     /// Construct an Array with copies of **elem**.
     ///
-    /// ## Example
-    ///
     /// ```
     /// use ndarray::Array;
     /// use ndarray::arr3;
@@ -382,8 +390,6 @@ impl<A, D> Array<A, D> where D: Dimension
     ///
     /// See broadcasting documentation for Numpy for more information.
     ///
-    /// ## Example
-    ///
     /// ```
     /// use ndarray::arr1;
     ///
@@ -678,6 +684,7 @@ impl<A, D> Array<A, D> where D: Dimension
     pub fn raw_data_mut<'a>(&'a mut self) -> &'a mut [A]
         where A: Clone
     {
+        self.ensure_unique();
         &mut Rc::make_mut(&mut self.data)[..]
     }
 
